Documentation
¶
Index ¶
- func Addparticipator(title string, participator []string) bool
- func CreateMeeting(userName, title, startDate, endDate string, participator []string) bool
- func CreateMeeting_DB(meeting *Meeting) error
- func CreateUser_DB(user *User) error
- func DeleteAllMeetings(name string) bool
- func DeleteMeeting(name, title string) bool
- func DeleteMeeting_DB(meeting *Meeting) error
- func DeleteUser(userName string, password string) bool
- func DeleteUser_DB(user *User) error
- func GetJson(v interface{}) string
- func IntToString(a int) string
- func QuitMeeting(title string) bool
- func ReadCurrentUser()
- func ReadFromDb()
- func Removeparticipator(title string, participator []string) bool
- func StartAgenda() bool
- func UpdateMeeting_DB(meeting *Meeting) error
- func UpdateUser_DB(user *User) error
- func UserLogIn(userName string, password string) bool
- func UserRegister(userName, password, email, phone string) bool
- type Date
- type Meeting
- type MeetingTable
- type User
- type UserTable
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Addparticipator ¶
* * add participator into the meetings created by sponsor * @param title meeting's title * @return if success, true will be returned
func CreateMeeting ¶
*
- create a meeting
- @param userName the sponsor's userName
- @param title the meeting's title
- @param participator the meeting's participator
- @param startData the meeting's start date
- @param endData the meeting's end date
- @return if success, true will be returned
func DeleteAllMeetings ¶
* * delete all meetings by sponsor * @param userName sponsor's username * @return if success, true will be returned
func DeleteMeeting ¶
* * delete a meeting by title and its sponsor * @param userName sponsor's username * @param title meeting's title * @return if success, true will be returned
func DeleteUser ¶
*
- delete a user
- @param userName user's username
- @param password user's password
- @return if success, true will be returned
func IntToString ¶
func QuitMeeting ¶
* * CurrentUser quits meeting in which the currentUser participate * @param title meeting's title * @return if success, true will be returned
func ReadCurrentUser ¶
func ReadCurrentUser()
func Removeparticipator ¶
* * remove participator from the meetings created by sponsor * @param title meeting's title * @return if success, true will be returned
func StartAgenda ¶
func StartAgenda() bool
func UpdateMeeting_DB ¶
func UserLogIn ¶
* * check if the username match password * @param userName the username want to login * @param password the password user enter * @return if success, true will be returned
登录命令不需要调用StartAgenda,但需要调用QuitAgenda来保存登录信息
func UserRegister ¶
*
- regist a user
- @param userName new user's username
- @param password new user's password
- @param email new user's email
- @param phone new user's phone
- @return if success, true will be returned
Types ¶
type Meeting ¶
type Meeting struct {
Sponsor string
Title string
StartDate string
EndDate string
Participators []string
}
func ListAllMeetings ¶
* * list all meetings the user take part in * @param userName user's username * @return a meeting list result
func ListAllParticipateMeetings ¶
* * list all meetings the user take part in and sponsor by other * @param userName user's username * @return a meeting list result
func ListAllSponsorMeetings ¶
* * delete a meeting by title and its sponsor * @param userName sponsor's username * @param title meeting's title * @return if success, true will be returned
func MeetingQuery ¶
* * search a meeting by username, time interval (user as sponsor or participator) * @param uesrName the user's userName * @param startDate time interval's start date * @param endDate time interval's end date * @return a meeting list result